Adding reference to the wiki on README
[xmenu] / config.h
index a3e4f95..aec217e 100644 (file)
--- a/config.h
+++ b/config.h
@@ -1,20 +1,34 @@
-/* font */
-static const char *font = "monospace:size=9";    /* for regular items */
+static struct Config config = {
+       /* font, separate different fonts with comma */
+       .font = "monospace:size=9,DejaVuSansMono:size=9",
 
 
-/* colors */
-static const char *background_color = "#FFFFFF";
-static const char *foreground_color = "#2E3436";
-static const char *selbackground_color = "#3584E4";
-static const char *selforeground_color = "#FFFFFF";
-static const char *separator_color = "#CDC7C2";
-static const char *border_color = "#E6E6E6";
+       /* colors */
+       .background_color = "#FFFFFF",
+       .foreground_color = "#2E3436",
+       .selbackground_color = "#3584E4",
+       .selforeground_color = "#FFFFFF",
+       .separator_color = "#CDC7C2",
+       .border_color = "#E6E6E6",
 
 
-/* sizes in pixels */
-static int width_pixels = 130;      /* minimum width of a menu */
-static int padding_pixels = 4;      /* padding around label in a item */
-static int border_pixels = 1;       /* menu border */
-static int separator_pixels = 3;    /* space around separator */
+       /* sizes in pixels */
+       .width_pixels = 130,        /* minimum width of a menu */
+       .height_pixels = 25,        /* height of a single menu item */
+       .border_pixels = 1,         /* menu border */
+       .separator_pixels = 3,      /* space around separator */
+       .gap_pixels = 0,            /* gap between menus */
 
 
-/* geometry of the right-pointing isoceles triangle for submenus */
-static const int triangle_width = 3;
-static const int triangle_height = 7;
+       /*
+        * The variables below cannot be set by X resources.
+        * Their values must be less than .height_pixels.
+        */
+
+       /* geometry of the right-pointing isoceles triangle for submenus */
+       .triangle_width = 3,
+       .triangle_height = 7,
+
+       /* the icon size is equal to .height_pixels - .iconpadding * 2 */
+       .iconpadding = 2,
+
+       /* area around the icon, the triangle and the separator */
+       .horzpadding = 8,
+};